@@ -2,10 +2,10 @@ import copy
 
 import botocore.parsers
 import botocore.serialize
-from botocore.args import ClientArgsCreator
+from botocore.args import ClientArgsCreator, EPRBuiltins
 
 from .config import AioConfig
-from .endpoint import AioEndpointCreator
+from .endpoint import DEFAULT_HTTP_SESSION_CLS, AioEndpointCreator
 from .regions import AioEndpointRulesetResolver
 from .signers import AioRequestSigner
 
@@ -47,9 +47,9 @@ class AioClientArgsCreator(ClientArgsCreator):
         partition = endpoint_config['metadata'].get('partition', None)
         socket_options = final_args['socket_options']
         configured_endpoint_url = final_args['configured_endpoint_url']
-
         signing_region = endpoint_config['signing_region']
         endpoint_region_name = endpoint_config['region_name']
+        account_id_endpoint_mode = config_kwargs['account_id_endpoint_mode']
 
         event_emitter = copy.copy(self._event_emitter)
         signer = AioRequestSigner(
@@ -67,8 +67,10 @@ class AioClientArgsCreator(ClientArgsCreator):
         # aiobotocore addition
         if isinstance(client_config, AioConfig):
             connector_args = client_config.connector_args
+            http_session_cls = client_config.http_session_cls
         else:
             connector_args = None
+            http_session_cls = DEFAULT_HTTP_SESSION_CLS
 
         new_config = AioConfig(connector_args, **config_kwargs)
         endpoint_creator = AioEndpointCreator(event_emitter)
@@ -79,9 +81,10 @@ class AioClientArgsCreator(ClientArgsCreator):
             endpoint_url=endpoint_config['endpoint_url'],
             verify=verify,
             response_parser_factory=self._response_parser_factory,
-            max_pool_connections=new_config.max_pool_connections,
-            proxies=new_config.proxies,
             timeout=(new_config.connect_timeout, new_config.read_timeout),
+            max_pool_connections=new_config.max_pool_connections,
+            http_session_cls=http_session_cls,
+            proxies=new_config.proxies,
             socket_options=socket_options,
             client_cert=new_config.client_cert,
             proxies_config=new_config.proxies_config,
@@ -105,6 +108,8 @@ class AioClientArgsCreator(ClientArgsCreator):
             is_secure,
             endpoint_bridge,
             event_emitter,
+            credentials,
+            account_id_endpoint_mode,
         )
 
         # Copy the session's user agent factory and adds client configuration.
@@ -142,6 +147,8 @@ class AioClientArgsCreator(ClientArgsCreator):
         is_secure,
         endpoint_bridge,
         event_emitter,
+        credentials,
+        account_id_endpoint_mode,
     ):
         if endpoints_ruleset_data is None:
             return None
@@ -166,7 +173,15 @@ class AioClientArgsCreator(ClientArgsCreator):
             endpoint_bridge=endpoint_bridge,
             client_endpoint_url=endpoint_url,
             legacy_endpoint_url=endpoint.host,
+            credentials=credentials,
+            account_id_endpoint_mode=account_id_endpoint_mode,
         )
+
+        # replace with async version
+        resolver_builtins[EPRBuiltins.ACCOUNT_ID] = (
+            credentials.get_account_id if credentials else None
+        )
+
         # Client context params for s3 conflict with the available settings
         # in the `s3` parameter on the `Config` object. If the same parameter
         # is set in both places, the value in the `s3` parameter takes priority.
